pub struct App { /* private fields */ }Implementations
Sourceimpl App
impl App
Sourcepub fn handle_events(&mut self) -> Result<(), Error>
pub fn handle_events(&mut self) -> Result<(), Error>
Polls for input events and dispatches them to the app.
Errors
Returns an error if event polling or reading fails.
Sourceimpl App
impl App
pub fn new() -> Self
pub fn refresh_tunnels(&mut self)
pub fn should_quit(&self) -> bool